@@ -42,11 +42,11 @@ class PersistentAdapterRegistryTests(unittest.TestCase):
 
     def _makeJar(self):
         # Borrowed from persistent.tests.test_pyPersistence.
-        from zope.interface import implements
+        from zope.interface import implementer
         from persistent.interfaces import IPersistentDataManager
 
+        @implementer(IPersistentDataManager)
         class _Jar(object):
-            implements(IPersistentDataManager)
             def __init__(self):
                 self._loaded = []
                 self._registered = []
